<?php

//
// innovaphone PBX SOAP API PHP wrapper class
// copyright (c) innovaphone 2012 - 2015
//

require_once('soap.client.timeout.class.php');

class InnovaphonePbx extends SoapClientTimeout {

    protected $key;         // the session key
    protected $session;     // the session id
    protected $faultString;

    protected $options = array(
        "connection_timeout"    => 10000,
        "timeout"               => 65000,
        "sslverifypeer"         => false,
        "sslverifyhost"         => 1,
        "exceptions"            => true,
        );

    const wsdl = 'http://www.innovaphone.com/wsdl/pbx10_00.wsdl';

    // class constructor
    public function __construct(
        $server,                // the PBX IP
        $port,                  // the PBX port
        $https,                 // use HTTPS to the PBX
        $httpu,                 // the HTTP user id (e.g. "admin")
        $httpp,                 // the HTTP password (e.g. "ip800")
        $user,                  // the PBX user CN to work with 
        $appDescription = null,
        $options        = null, // extra or overriding options for SOAPClient::__construct
        $wsdl           = null, // the wsdl file location
        $dynPbxId       = null) // the dyn PBX Id
    {    
        $wsdl = ($wsdl === null) ? self::wsdl : $wsdl;
        $usedoptions = array(            // forced options
            'login'     => $httpu,
            'password'  => $httpp,
            'location'  => 
            "http" . ($https ? "s" : "") . "://$server" . 
            ($port != "" ? (":" . $port) : "") .
            "/PBX0" . ($dynPbxId != "" ? ("-" . $dynPbxId) : "") . "/user.soap",
            );
        
        if(is_array($options)) {
            $usedoptions = $options + $usedoptions;
        }
        
        // merge in user options
        $usedoptions += $this->options;    // merged in class global options
        $this->key           = 0;
        $this->session       = 0;
        $this->faultString   = null;

        // construct parent class
        try {
            parent::__construct($wsdl, $usedoptions);
        }
        catch (Exception $e) {
            $this->faultString   = $e->getMessage() . $e->faultstring;
            return;
        }         

        if($user != "") {
            try {
                $init           = $this->Initialize($user, $appDescription ? $appDescription : "PHP SOAP Wrapper", true, true, true, true, true);
                $this->key      = $init['key'];
                $this->session  = $init['return'];
                if($init['key'] == 0) {
                    $this->faultString   = "Session initialize failure.";
                }
                else {
                    $this->faultString   = null;
                }
            }
            catch (Exception $e) {
                $this->key          = 0;
                $this->session      = 0;
                $responseHeaders    = $this->__getLastResponseHeaders();
                $response           = $this->__getLastResponse();
                $this->faultString  = $e->getMessage() . $e->faultstring . ($responseHeaders != "" ? ":\n" : "") .  $responseHeaders . ($response != "" ? ":\n" : "") . $response;
            }         
        }
    }

    public function getKey() { return $this->key; }
    public function getSession() { return $this->session; }
    public function getFaultString() { return $this->faultString; }

    public function showVersion() {
        try {
            // get version info and show info
            $v = $this->Version();
            if($v['FirmwareVersion']) {
                printf("  %-17s %s\n", "Firmware Version:", $v['FirmwareVersion']); 
            }
            if($v['SerialNumber']) {
                printf("  %-17s %s\n", "Serial Number:", $v['SerialNumber']); 
            }
        }
        catch (Exception $e) {
        }
    }
}

?>
